==> vtigercrm-5.3.0p0.tgz: modules/Faq/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'FAQ',
'LBL_MODULE_TITLE'=>'FAQ: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar FAQ',
'LBL_LIST_FORM_TITLE'=>'Lista de FAQ',
'LBL_NEW_FORM_TITLE'=>'Nova FAQ',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizações Membro',

'LBL_LIST_ACCOUNT_NAME'=>'Nome da FAQ',
'LBL_LIST_CITY'=>'Cidade',
'LBL_LIST_WEBSITE'=>'Website',
'LBL_LIST_STATE'=>'Estado',
'LBL_LIST_PHONE'=>'Fone',
'LBL_LIST_EMAIL_ADDRESS'=>'Endereço Email',
'LBL_LIST_CONTACT_NAME'=>'Nome Contato',
'LBL_FAQ_INFORMATION'=>'Informação FAQ',
      
//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',
      
//END DON'T CONVERT
      
'LBL_ACCOUNT'=>'FAQ:',
'LBL_ACCOUNT_NAME'=>'Nome FAQ:',
'LBL_PHONE'=>'Fone:',
'LBL_WEBSITE'=>'Website:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Cód. Bolsa:',
'LBL_OTHER_PHONE'=>'Telefone Alternativo:',
'LBL_ANY_PHONE'=>'Outro Telefone:',
'LBL_MEMBER_OF'=>'Membro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empregados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email Alternativo:',
'LBL_ANY_EMAIL'=>'Outro Email:',
'LBL_OWNERSHIP'=>'Propriedade:',
'LBL_RATING'=>'Avaliação:',
'LBL_INDUSTRY'=>'Atividade:',
'LBL_SIC_CODE'=>'Cod CNAE:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Receita Anual:',
'LBL_ADDRESS_INFORMATION'=>'Dados do Endereço',
'LBL_ACCOUNT_INFORMATION'=>'Dados da FAQ',
'LBL_BILLING_ADDRESS'=>'Endereço:',
'LBL_SHIPPING_ADDRESS'=>'Endereço Entrega:',
'LBL_ANY_ADDRESS'=>'Outro Endereço:',
'LBL_CITY'=>'Cidade:',
'LBL_STATE'=>'Estado:',
'LBL_POSTAL_CODE'=>'CEP:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',
'LBL_DESCRIPTION'=>'Descrição:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar endereço de Faturamento para endereço Entrega',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar endereço de Entrega para endereço de Faturamento',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'Você tem certeza que deseja remover este registro como uma organização membro?',
'LBL_DUPLICATE'=>'Possibilidade de FAQ Duplicada',
'MSG_DUPLICATE' => 'Criando esta Conta pode ser que a vtiger_potentialy crie uma vtiger_account duplicada. Você pode seleciona uma outra Conta da lista abaixo ou clicar sobre Criar Nova FAQ para continuar criando uma nova Conta com os dados previamente inseridos.',

'LBL_INVITEE'=>'Contatos',
'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a Conta.",

'LBL_SELECT_ACCOUNT'=>'Selecione FAQ',
'LBL_GENERAL_INFORMATION'=>'Informação Geral',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nova Tarefa',
'LBL_TASK_TITLE'=>'Tarefa',
'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',
'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reunião',
'LBL_NEW_EMAIL'=>'Novo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',

//Added for 4GA Release
'Category'=>'Categoria',
'Related To'=>'Relacionado à',
'Question'=>'Questão',
'Answer'=>'Resposta',
'Comments'=>'Comentários',
'LBL_COMMENTS'=>'Comments',//give the same value given to the above string 'Comments'
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',

//Added vtiger_fields after 4.2 alpha
'LBL_TICKETS'=>'Tickets',
'LBL_FAQ'=>'FAQ',
'Product Name'=>'Nome Produto',
'FAQ Id'=>'No. FAQ',
'Add Comment'=>'Adicionar Comentário',
'LBL_ADD_COMMENT'=>'Add Comment',//give the same value given to the above string 'Add Comment'
'LBL_COMMENT_INFORMATION'=>'Dados do Comentário',
'Status'=>'Status',

//Added on 10-12-2005
'LBL_QUESTION'=>'Questão',
'LBL_CATEGORY'=>'Categoria',
'LBL_MY_FAQ'=>'FAQs Recentes',

//Added for existing Picklist Entries

'General'=>'Geral',

'Draft'=>'Rascunho',
'Reviewed'=>'Revisada',
'Published'=>'Publicada',
'Obsolete'=>'Obsoleta',

// Module Sequence Numbering
'Faq No' => 'No. Faq',
// END

);

?>

==> vtigercrm-5.4.0.tgz: modules/Faq/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header$
 * Description:  Defines the English language pack for FAQ Module
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'FAQ',
'LBL_MODULE_TITLE'=>'FAQ: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar FAQ',
'LBL_LIST_FORM_TITLE'=>'Lista de FAQ',
'LBL_NEW_FORM_TITLE'=>'Nova FAQ',
'LBL_MEMBER_ORG_FORM_TITLE'=>'Organizações Membro',

'LBL_LIST_ACCOUNT_NAME'=>'Nome da FAQ',
'LBL_LIST_CITY'=>'Cidade',
'LBL_LIST_WEBSITE'=>'Website',
'LBL_LIST_STATE'=>'Estado',
'LBL_LIST_PHONE'=>'Fone',
'LBL_LIST_EMAIL_ADDRESS'=>'Endereço Email',
'LBL_LIST_CONTACT_NAME'=>'Nome Contato',
'LBL_FAQ_INFORMATION'=>'Informação FAQ',
      
//DON'T CONVERT THESE THEY ARE MAPPINGS
'db_name' => 'LBL_LIST_ACCOUNT_NAME',
'db_website' => 'LBL_LIST_WEBSITE',
'db_billing_address_city' => 'LBL_LIST_CITY',
      
//END DON'T CONVERT
      
'LBL_ACCOUNT'=>'FAQ:',
'LBL_ACCOUNT_NAME'=>'Nome FAQ:',
'LBL_PHONE'=>'Fone:',
'LBL_WEBSITE'=>'Website:',
'LBL_FAX'=>'Fax:',
'LBL_TICKER_SYMBOL'=>'Cód. Bolsa:',
'LBL_OTHER_PHONE'=>'Telefone Alternativo:',
'LBL_ANY_PHONE'=>'Outro Telefone:',
'LBL_MEMBER_OF'=>'Membro de:',
'LBL_EMAIL'=>'Email:',
'LBL_EMPLOYEES'=>'Empregados:',
'LBL_OTHER_EMAIL_ADDRESS'=>'Email Alternativo:',
'LBL_ANY_EMAIL'=>'Outro Email:',
'LBL_OWNERSHIP'=>'Propriedade:',
'LBL_RATING'=>'Avaliação:',
'LBL_INDUSTRY'=>'Atividade:',
'LBL_SIC_CODE'=>'Cod CNAE:',
'LBL_TYPE'=>'Tipo:',
'LBL_ANNUAL_REVENUE'=>'Receita Anual:',
'LBL_ADDRESS_INFORMATION'=>'Dados do Endereço',
'LBL_ACCOUNT_INFORMATION'=>'Dados da FAQ',
'LBL_BILLING_ADDRESS'=>'Endereço:',
'LBL_SHIPPING_ADDRESS'=>'Endereço Entrega:',
'LBL_ANY_ADDRESS'=>'Outro Endereço:',
'LBL_CITY'=>'Cidade:',
'LBL_STATE'=>'Estado:',
'LBL_POSTAL_CODE'=>'CEP:',
'LBL_COUNTRY'=>'País:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição',
'LBL_DESCRIPTION'=>'Descrição:',
'NTC_COPY_BILLING_ADDRESS'=>'Copiar endereço de Faturamento para endereço Entrega',
'NTC_COPY_SHIPPING_ADDRESS'=>'Copiar endereço de Entrega para endereço de Faturamento',
'NTC_REMOVE_MEMBER_ORG_CONFIRMATION'=>'Você tem certeza que deseja remover este registro como uma organização membro?',
'LBL_DUPLICATE'=>'Possibilidade de FAQ Duplicada',
'MSG_DUPLICATE' => 'Criando esta Organização pode ser que a vtiger_potentialy crie uma vtiger_account duplicada. Você pode seleciona uma outra Organização da lista abaixo ou clicar sobre Criar Nova FAQ para continuar criando uma nova Organização com os dados previamente inseridos.',

'LBL_INVITEE'=>'Contatos',
'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a Organização.",

'LBL_SELECT_ACCOUNT'=>'Selecione FAQ',
'LBL_GENERAL_INFORMATION'=>'Informação Geral',

//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nova Tarefa',
'LBL_TASK_TITLE'=>'Tarefa',
'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',
'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reunião',
'LBL_NEW_EMAIL'=>'Novo Email',
'LBL_EMAIL_TITLE'=>'Emails',
'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',

//Added for 4GA Release
'Category'=>'Categoria',
'Related To'=>'Relacionado à',
'Question'=>'Questão',
'Answer'=>'Resposta',
'Comments'=>'Comentários',
'LBL_COMMENTS'=>'Comments',//give the same value given to the above string 'Comments'
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',

//Added vtiger_fields after 4.2 alpha
'LBL_TICKETS'=>'Tickets',
'LBL_FAQ'=>'FAQ',
'Product Name'=>'Nome Produto',
'FAQ Id'=>'No. FAQ',
'Add Comment'=>'Adicionar Comentário',
'LBL_ADD_COMMENT'=>'Add Comment',//give the same value given to the above string 'Add Comment'
'LBL_COMMENT_INFORMATION'=>'Dados do Comentário',
'Status'=>'Status',

//Added on 10-12-2005
'LBL_QUESTION'=>'Questão',
'LBL_CATEGORY'=>'Categoria',
'LBL_MY_FAQ'=>'FAQs Recentes',

//Added for existing Picklist Entries

'General'=>'Geral',

'Draft'=>'Rascunho',
'Reviewed'=>'Revisada',
'Published'=>'Publicada',
'Obsolete'=>'Obsoleta',

// Module Sequence Numbering
'Faq No' => 'No. Faq',
// END
'Faq ID' => 'ID FAQ',
);

?>
